  /*  **********************************************************************
    Source:     TM_Test.C

    Purpose:    this module contains the Test stuff
    **********************************************************************/

#include	<windows.h>
#include	<windowsx.h> 
#include	"tcpmdlw.h"   
#include	"testpgm.h"
 

//  -----------------------------------------------------------------
//  TM_Test     open the session between the server and self

int PASCAL WinMain (HANDLE hInstance, HANDLE hPrevInstance,
                    LPSTR szCmdLine, int nCmdShow)
   {
	HWND     hwnd;
    MSG      msg;
    WNDCLASS wndclass;                   
    LOGFONT  lf;
   
		
   ghInstance = hInstance;		// global instance   

   if (!hPrevInstance) 
   {
      wndclass.style         = CS_HREDRAW | CS_VREDRAW;
      wndclass.lpfnWndProc   = WndProc;
      wndclass.cbClsExtra    = 0;
      wndclass.cbWndExtra    = 0;
      wndclass.hInstance     = hInstance;
      wndclass.hIcon         = LoadIcon (NULL, IDI_APPLICATION);
      wndclass.hCursor       = LoadCursor (NULL, IDC_ARROW);
      wndclass.hbrBackground = GetStockObject (WHITE_BRUSH);
      wndclass.lpszMenuName  = MAKEINTRESOURCE(MENU_MAIN);
      wndclass.lpszClassName = "MainWndClass";

      RegisterClass (&wndclass);
   }

   hwnd = CreateWindow ("MainWndClass", "TCP/IP Middleware Tester",
                        WS_OVERLAPPEDWINDOW,
                        CW_USEDEFAULT, CW_USEDEFAULT,
                        500, 300,
                        NULL, NULL, hInstance, NULL);            	
 
    hMainWindow = hwnd;

    hDebugWindow = CreateWindow("EDIT", NULL,
            WS_CHILD | WS_VISIBLE | WS_BORDER | WS_VSCROLL | WS_HSCROLL |
            ES_AUTOHSCROLL | ES_AUTOVSCROLL | ES_MULTILINE,
            0, 0, 0, 0,
            hMainWindow, (HMENU)0, hInstance, NULL);

    if (!hDebugWindow)
        return FALSE;

    // Use the small icon title font
    //
    SystemParametersInfo(SPI_GETICONTITLELOGFONT, sizeof(lf), &lf, FALSE);
    hfontClient = CreateFontIndirect(&lf);
    if (hfontClient)
        SendMessage(hDebugWindow, WM_SETFONT, (WPARAM)(UINT)hfontClient, 1);

    ShowWindow(hMainWindow, nCmdShow);
 
    ShowWindow(hDebugWindow, SW_SHOWNORMAL);


   while (GetMessage (&msg, NULL, 0, 0))
   {
      TranslateMessage (&msg);
      DispatchMessage (&msg);
   }

	return msg.wParam;

}  


//***********************************************************************
// Function:    WndProc()
//
// Purpose:     Main Window procedure
//
//***********************************************************************

LRESULT CALLBACK WndProc (HWND hWnd, WORD uMsg, WORD wParam,
							  LONG lParam)
{                                       
LPTESTBLOCK	lpTestBlock;

   switch (uMsg)
   { 
		case TM_EVENT:                             
			lpTestBlock = (LPTESTBLOCK) lParam;
			(lpTestBlock->func)(lpTestBlock, wParam);
			break;
			   	  		
		case WM_COMMAND:    
			switch (wParam)
			{
				case ID_FILE_EXIT:
				   DestroyWindow(hWnd);
				   return 0;
								    	
				case ID_NEWS_TEST1:   
					lpTestBlock = initTest(*newsTest1);
				   return 0;
								    	
				case ID_NEWS_TEST2:
					lpTestBlock = initTest(*newsTest2);
				   return 0;    
							               
				case ID_NEWS_TEST3:
					lpTestBlock = initTest(*newsTest3);
				   return 0;

				case ID_NEWS_TEST4:
					lpTestBlock = initTest(*newsTest4);
				   return 0;

				case ID_NEWS_TEST5:
					lpTestBlock = initTest(*newsTest5);
				   return 0;

				case ID_SMTP_TEST1:   
					lpTestBlock = initTest(*smtpTest1);
				   return 0;

				case ID_SMTP_TEST2:   
					lpTestBlock = initTest(*smtpTest2);
				   return 0;

				case ID_SMTP_TEST3:   
					lpTestBlock = initTest(*smtpTest3);
				   return 0;

				case ID_POP_TEST1:   
					lpTestBlock = initTest(*popTest1);
				   return 0;

				case ID_POP_TEST2:
					lpTestBlock = initTest(*popTest2);
				   return 0;    

				case ID_POP_TEST3:
					lpTestBlock = initTest(*popTest3);
				   return 0;    

				case ID_MULTI_TEST1:
					lpTestBlock = initTest(*newsTest1);
					lpTestBlock = initTest(*popTest1);
				   return 0;    
			}
		  	break;

		case WM_ACTIVATE:
		    if (wParam)             		        SetFocus(hDebugWindow);
		    break;
		
		case WM_SIZE:
		    /* Make sure the edit control always occupies the entire
		     * client area.
		     */
		    if (hDebugWindow)
		    {
		        RECT rc;
		
		        GetClientRect(hWnd, &rc);
		        //
		        // Outset border
		        //
		        InflateRect(&rc, 1, 1);
		        MoveWindow(hDebugWindow, rc.top, rc.left, rc.right - rc.left, rc.bottom - rc.top, TRUE);
		    }
		    break;

           
      case WM_DESTROY:
         PostQuitMessage (0) ;
         return 0 ;
   }

   return DefWindowProc (hWnd, uMsg, wParam, lParam) ;
}  



LPTESTBLOCK	initTest (PFNTESTER func)
{

GLOBALHANDLE	hBlock;
LPTESTBLOCK		lpTestBlock;
	
	hBlock = GlobalAlloc(GHND, sizeof(TESTBLOCK));
	lpTestBlock = (LPTESTBLOCK) GlobalLock(hBlock);
	lpTestBlock->state = IDLE; 
	hBlock = GlobalAlloc(GHND, sizeof(TMEVENT));
	lpTestBlock->lpEvent = (LPTMEVENT) GlobalLock(hBlock);
	lpTestBlock->hBfr = GlobalAlloc(GHND, BFRLEN);
	lpTestBlock->lpBfr = GlobalLock(lpTestBlock->hBfr);

	lpTestBlock->func = func;
	lpTestBlock->func(lpTestBlock, 0);
	
	return lpTestBlock;
}	


void	termTest (LPTESTBLOCK lpTestBlock)
{
	tmTerm(lpTestBlock);
	
	GlobalFreePtr(lpTestBlock->lpBfr);
	GlobalFreePtr(lpTestBlock->lpEvent);
	GlobalFreePtr(lpTestBlock);
}	


void OutputDebug(LPSTR lpBfr)
{
    int cLines;

    // First see if we will exceed our line maximum
    //
    cLines = Edit_GetLineCount(hDebugWindow);
    if (cLines > LINESMAX)
    {
        Edit_SetSel(hDebugWindow, 0, Edit_LineIndex(hDebugWindow, cLines - LINESMAX));
        Edit_ReplaceSel(hDebugWindow, "");
    }

    // Append to the end of the buffer.
    //
    Edit_SetSel(hDebugWindow, 32767, 32767);
    Edit_ReplaceSel(hDebugWindow, lpBfr);
    Edit_SetSel(hDebugWindow, 32767, 32767);  
    Edit_ReplaceSel(hDebugWindow, "\x0d\x0a");
    Edit_SetSel(hDebugWindow, 32767, 32767);  
}  
       
       
void	ResetDebug()
{
    Edit_SetSel(hDebugWindow, 0, 32767);
    Edit_ReplaceSel(hDebugWindow, "");
}
